==> nextcloud-app-calendar-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/de_DE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} Fehler)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "%s has published the calendar \"%s\"" : "%s hat den Kalender \"%s\" veröffentlicht",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "erforderlich",
    "Optional" : "optional",
    "Does not attend" : "Nimmt nicht teil",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sie sind in einer unbekannten Zeitzone ({tz}), es wird auf UTC geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neuer Termin",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "EMail has been sent." : "E-Mail wurde versendet.",
    "There was an issue while sending your EMail." : "Es ist ein Fehler beim Versenden der E-Mail aufgetreten.",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "Wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "wenn geteilt, zeige nur 'beschäftigt'",
    "When shared hide this event" : "wenn geteilt, zeige den Termin nicht an",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "Abgebrochen",
    "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
    "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "Jeden Tag",
    "Every week" : "Jede Woche",
    "Every month" : "Jeden Monat",
    "Every year" : "Jedes Jahr",
    "never" : "Niemals",
    "after" : "Nach",
    "How about getting started by importing some calendars?" : "Wie wäre es, wenn Sie damit beginnen würden einige Kalender zu importieren?",
    "At time of event" : "Zum Zeitpunkt des Termins",
    "5 minutes before" : "5 Minuten vor",
    "10 minutes before" : "10 Minuten vor",
    "15 minutes before" : "15 Minuten vor",
    "30 minutes before" : "30 Minuten vor",
    "1 hour before" : "1 Stunde vor",
    "2 hours before" : "2 Stunden vor",
    "Custom" : "Benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-Up",
    "sec" : "Sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tage",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert, {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Termins",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Termins",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Termins",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Termins",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte geben Sie eine gültige WebCal-URL an",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktieren Sie Ihren Administrator für weitere Informationen.",
    "Title of the Event" : "Titel der Veranstaltung",
    "starts" : "Beginnt",
    "ends" : "endet",
    "All day Event" : "Ganztägige Veranstaltung",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr...",
    "Create" : "Erstellen",
    "Update" : "Update durchführen",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Veranstaltungsstatus",
    "Visibility when sharing" : "Geteilte Ansicht",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollen Sie informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicken Sie hier, um darauf zuzugreifen",
    "Cheers!" : "Noch einen schönen Tag!",
    "We wanted to inform you that %s has published the calendar %s." : "Wir wollen Sie informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicken Sie auf den unteren Link, um darauf zuzugreifen",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktieren Sie ihren Administrator und bitten Sie ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfen Sie die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender freigeben",
    "Shared" : "Geteilt",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "WebCal URL" : "WebCal-URL",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link teilen",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "neues Abonnement",
    "WebCal-URL" : "WebCal-URL",
    "Go back" : "Zurück gehen",
    "Go forward" : "Weiter gehen",
    "Edit event" : "Termin bearbeiten",
    "Delete Event" : "Termin löschen",
    "Save Event" : "Termin speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte fügen Sie ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "wiederhole jeden ...",
    "end repeat ..." : "Wiederholung beenden ...",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Importieren abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält ein Objekt, dass inkompatibel ist mit dem ausgewählten Kalender",
    "New calendar" : "Neuer Kalender",
    "File is empty" : "Datei ist leer",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Publish URL" : "URL veröffentlichen",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Settings & import" : "Einstellungen & Import",
    "Skip simple event editor" : "Einfachen Termin-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalendar importieren",
    "No Calendars selected for import" : "Es wurde kein Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/de_DE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s hat den Kalender \"%s\" veröffentlicht",
    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} Fehler)",
    "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
    "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "erforderlich",
    "Optional" : "optional",
    "Does not attend" : "Nimmt nicht teil",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sie sind in einer unbekannten Zeitzone ({tz}), es wird auf UTC geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neuer Termin",
    "CalDAV address for clients" : "CalDAV-Adresse für Clients",
    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
    "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
    "EMail has been sent." : "E-Mail wurde versendet.",
    "There was an issue while sending your EMail." : "Es ist ein Fehler beim Versenden der E-Mail aufgetreten.",
    "group" : "Gruppe",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "Wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "wenn geteilt, zeige nur 'beschäftigt'",
    "When shared hide this event" : "wenn geteilt, zeige den Termin nicht an",
    "Confirmed" : "Bestätigt",
    "Tentative" : "Vorläufig",
    "Cancelled" : "Abgebrochen",
    "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
    "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "Jeden Tag",
    "Every week" : "Jede Woche",
    "Every month" : "Jeden Monat",
    "Every year" : "Jedes Jahr",
    "never" : "Niemals",
    "after" : "Nach",
    "How about getting started by importing some calendars?" : "Wie wäre es, wenn Sie damit beginnen würden einige Kalender zu importieren?",
    "At time of event" : "Zum Zeitpunkt des Termins",
    "5 minutes before" : "5 Minuten vor",
    "10 minutes before" : "10 Minuten vor",
    "15 minutes before" : "15 Minuten vor",
    "30 minutes before" : "30 Minuten vor",
    "1 hour before" : "1 Stunde vor",
    "2 hours before" : "2 Stunden vor",
    "Custom" : "Benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-Up",
    "sec" : "Sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tage",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert, {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn des Termins",
    "{type} {time} before the event ends" : "{type} {time} vor Ende des Termins",
    "{type} {time} after the event starts" : "{type} {time} nach Beginn des Termins",
    "{type} {time} after the event ends" : "{type} {time} nach Ende des Termins",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Please enter a valid WebCal-URL" : "Bitte geben Sie eine gültige WebCal-URL an",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktieren Sie Ihren Administrator für weitere Informationen.",
    "Title of the Event" : "Titel der Veranstaltung",
    "starts" : "Beginnt",
    "ends" : "endet",
    "All day Event" : "Ganztägige Veranstaltung",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr...",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Event status" : "Veranstaltungsstatus",
    "Visibility when sharing" : "Geteilte Ansicht",
    "Export" : "Exportieren",
    "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollen Sie informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
    "Click here to access it" : "Klicken Sie hier, um darauf zuzugreifen",
    "Cheers!" : "Noch einen schönen Tag!",
    "We wanted to inform you that %s has published the calendar %s." : "Wir wollen Sie informieren, dass %s den Kalender %s veröffentlicht hat.",
    "Click on the link below to access it" : "Klicken Sie auf den unteren Link, um darauf zuzugreifen",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktieren Sie ihren Administrator und bitten Sie ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfen Sie die JavaScript-Konsole für weitere Informationen.",
    "Share Calendar" : "Kalender freigeben",
    "Shared" : "Geteilt",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "iCal link" : "iCal-Link",
    "Download" : "Herunterladen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "can edit" : "kann bearbeiten",
    "Share link" : "Link teilen",
    "Public access" : "Öffentlicher Zugriff",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "New Calendar" : "Neuer Kalender",
    "Name" : "Name",
    "New Subscription" : "neues Abonnement",
    "Go back" : "Zurück gehen",
    "Go forward" : "Weiter gehen",
    "Edit event" : "Termin bearbeiten",
    "Delete Event" : "Termin löschen",
    "Save Event" : "Termin speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte fügen Sie ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "wiederhole jeden ...",
    "end repeat ..." : "Wiederholung beenden ...",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Importieren abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält ein Objekt, dass inkompatibel ist mit dem ausgewählten Kalender",
    "New calendar" : "Neuer Kalender",
    "File is empty" : "Datei ist leer",
    "Import scheduled" : "Import geplant",
    "Subscribe & embed" : "Abonnieren & einbetten",
    "Publish URL" : "URL veröffentlichen",
    "Iframe to integrate" : "Iframe zum Einbinden",
    "Settings & import" : "Einstellungen & Import",
    "Skip simple event editor" : "Einfachen Termin-Editor überspringen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Es wurde kein Kalender für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");
